==> aws-cdk-lib-2.195.0-sources.jar: software/amazon/awscdk/services/inspector/AssessmentTemplate.java <==
package software.amazon.awscdk.services.inspector;

/**
 * An Amazon Inspector assessment template.
 * <p>
 * TODO: This class should implement IAssessmentTemplate and "construct-ctor-props-type:aws-cdk-lib.aws_inspector.AssessmentTemplate" should be
 * removed from <code>awslint.json</code> when implementing the L2 construct
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.inspector.*;
 * CfnAssessmentTemplate cfnAssessmentTemplate;
 * IAssessmentTemplate assessmentTemplate = AssessmentTemplate.fromCfnAssessmentTemplate(this, "MyAssessmentTemplate", cfnAssessmentTemplate);
 * Schedule.Builder.create(this, "Schedule")
 *         .schedule(ScheduleExpression.rate(Duration.minutes(60)))
 *         .target(new InspectorStartAssessmentRun(assessmentTemplate))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.110.0 (build 336b265)", date = "2025-05-07T19:18:50.317Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_inspector.AssessmentTemplate")
public class AssessmentTemplate extends software.amazon.awscdk.Resource {

    protected AssessmentTemplate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AssessmentTemplate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public AssessmentTemplate(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.ResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public AssessmentTemplate(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Creates an AssessmentTemplate from an existing CfnAssessmentTemplate.
     * <p>
     * This method is provided to bridge the gap with L2 constructs since no L2 constructs
     * exist for Inspector resources yet. It allows working with CfnAssessmentTemplate (L1)
     * resources through the IAssessmentTemplate interface.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param template This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.inspector.IAssessmentTemplate fromCfnAssessmentTemplate(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.inspector.CfnAssessmentTemplate template) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.inspector.AssessmentTemplate.class, "fromCfnAssessmentTemplate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.inspector.IAssessmentTemplate.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(template, "template is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.inspector.AssessmentTemplate}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.inspector.AssessmentTemplate> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private software.amazon.awscdk.ResourceProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
        }

        /**
         * The AWS account ID this resource belongs to.
         * <p>
         * Default: - the resource is in the same account as the stack it belongs to
         * <p>
         * @return {@code this}
         * @param account The AWS account ID this resource belongs to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder account(final java.lang.String account) {
            this.props().account(account);
            return this;
        }

        /**
         * ARN to deduce region and account from.
         * <p>
         * The ARN is parsed and the account and region are taken from the ARN.
         * This should be used for imported resources.
         * <p>
         * Cannot be supplied together with either <code>account</code> or <code>region</code>.
         * <p>
         * Default: - take environment from `account`, `region` parameters, or use Stack environment.
         * <p>
         * @return {@code this}
         * @param environmentFromArn ARN to deduce region and account from. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder environmentFromArn(final java.lang.String environmentFromArn) {
            this.props().environmentFromArn(environmentFromArn);
            return this;
        }

        /**
         * The value passed in by users to the physical name prop of the resource.
         * <p>
         * <ul>
         * <li><code>undefined</code> implies that a physical name will be allocated by
         * CloudFormation during deployment.</li>
         * <li>a concrete value implies a specific physical name</li>
         * <li><code>PhysicalName.GENERATE_IF_NEEDED</code> is a marker that indicates that a physical will only be generated
         * by the CDK if it is needed for cross-environment references. Otherwise, it will be allocated by CloudFormation.</li>
         * </ul>
         * <p>
         * Default: - The physical name will be allocated by CloudFormation at deployment time
         * <p>
         * @return {@code this}
         * @param physicalName The value passed in by users to the physical name prop of the resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder physicalName(final java.lang.String physicalName) {
            this.props().physicalName(physicalName);
            return this;
        }

        /**
         * The AWS region this resource belongs to.
         * <p>
         * Default: - the resource is in the same region as the stack it belongs to
         * <p>
         * @return {@code this}
         * @param region The AWS region this resource belongs to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder region(final java.lang.String region) {
            this.props().region(region);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.inspector.AssessmentTemplate}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.inspector.AssessmentTemplate build() {
            return new software.amazon.awscdk.services.inspector.AssessmentTemplate(
                this.scope,
                this.id,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.ResourceProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.ResourceProps.Builder();
            }
            return this.props;
        }
    }
}

==> aws-cdk-lib-2.197.0-sources.jar: software/amazon/awscdk/services/inspector/AssessmentTemplate.java <==
package software.amazon.awscdk.services.inspector;

/**
 * An Amazon Inspector assessment template.
 * <p>
 * TODO: This class should implement IAssessmentTemplate and "construct-ctor-props-type:aws-cdk-lib.aws_inspector.AssessmentTemplate" should be
 * removed from <code>awslint.json</code> when implementing the L2 construct
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.inspector.*;
 * CfnAssessmentTemplate cfnAssessmentTemplate;
 * IAssessmentTemplate assessmentTemplate = AssessmentTemplate.fromCfnAssessmentTemplate(this, "MyAssessmentTemplate", cfnAssessmentTemplate);
 * Schedule.Builder.create(this, "Schedule")
 *         .schedule(ScheduleExpression.rate(Duration.minutes(60)))
 *         .target(new InspectorStartAssessmentRun(assessmentTemplate))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.112.0 (build de1bc80)", date = "2025-05-20T23:52:57.586Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_inspector.AssessmentTemplate")
public class AssessmentTemplate extends software.amazon.awscdk.Resource {

    protected AssessmentTemplate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AssessmentTemplate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        PROPERTY_INJECTION_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.inspector.AssessmentTemplate.class, "PROPERTY_INJECTION_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public AssessmentTemplate(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.ResourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public AssessmentTemplate(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Creates an AssessmentTemplate from an existing CfnAssessmentTemplate.
     * <p>
     * This method is provided to bridge the gap with L2 constructs since no L2 constructs
     * exist for Inspector resources yet. It allows working with CfnAssessmentTemplate (L1)
     * resources through the IAssessmentTemplate interface.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param template This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.inspector.IAssessmentTemplate fromCfnAssessmentTemplate(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.inspector.CfnAssessmentTemplate template) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.inspector.AssessmentTemplate.class, "fromCfnAssessmentTemplate", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.inspector.IAssessmentTemplate.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(template, "template is required") });
    }

    /**
     * Uniquely identifies this class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PROPERTY_INJECTION_ID;

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.inspector.AssessmentTemplate}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.inspector.AssessmentTemplate> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private software.amazon.awscdk.ResourceProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
        }

        /**
         * The AWS account ID this resource belongs to.
         * <p>
         * Default: - the resource is in the same account as the stack it belongs to
         * <p>
         * @return {@code this}
         * @param account The AWS account ID this resource belongs to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder account(final java.lang.String account) {
            this.props().account(account);
            return this;
        }

        /**
         * ARN to deduce region and account from.
         * <p>
         * The ARN is parsed and the account and region are taken from the ARN.
         * This should be used for imported resources.
         * <p>
         * Cannot be supplied together with either <code>account</code> or <code>region</code>.
         * <p>
         * Default: - take environment from `account`, `region` parameters, or use Stack environment.
         * <p>
         * @return {@code this}
         * @param environmentFromArn ARN to deduce region and account from. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder environmentFromArn(final java.lang.String environmentFromArn) {
            this.props().environmentFromArn(environmentFromArn);
            return this;
        }

        /**
         * The value passed in by users to the physical name prop of the resource.
         * <p>
         * <ul>
         * <li><code>undefined</code> implies that a physical name will be allocated by
         * CloudFormation during deployment.</li>
         * <li>a concrete value implies a specific physical name</li>
         * <li><code>PhysicalName.GENERATE_IF_NEEDED</code> is a marker that indicates that a physical will only be generated
         * by the CDK if it is needed for cross-environment references. Otherwise, it will be allocated by CloudFormation.</li>
         * </ul>
         * <p>
         * Default: - The physical name will be allocated by CloudFormation at deployment time
         * <p>
         * @return {@code this}
         * @param physicalName The value passed in by users to the physical name prop of the resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder physicalName(final java.lang.String physicalName) {
            this.props().physicalName(physicalName);
            return this;
        }

        /**
         * The AWS region this resource belongs to.
         * <p>
         * Default: - the resource is in the same region as the stack it belongs to
         * <p>
         * @return {@code this}
         * @param region The AWS region this resource belongs to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder region(final java.lang.String region) {
            this.props().region(region);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.inspector.AssessmentTemplate}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.inspector.AssessmentTemplate build() {
            return new software.amazon.awscdk.services.inspector.AssessmentTemplate(
                this.scope,
                this.id,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.ResourceProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.ResourceProps.Builder();
            }
            return this.props;
        }
    }
}
